@@ -6,6 +6,7 @@ import logging
 from string import Formatter
 from datetime import datetime
 
+import jinja2
 from dateutil.parser import parse as date_parser
 from docutils import nodes
 from docutils.parsers.rst import Directive, directives
@@ -369,9 +370,7 @@ def process_posts(app, doctree):
                         raise ValueError("invalid post date in: " + docname)
                 else:
                     raise ValueError(
-                        "invalid post date (%s) in " % (date)
-                        + docname
-                        + ". Expected format: %s" % post_date_format
+                        f"invalid post date ({date}) in " + docname + f". Expected format: {post_date_format}"
                     )
 
         else:
@@ -551,12 +550,13 @@ def _missing_reference(app, target, refdoc, contnode=None, refexplicit=False):
     if target in blog.references:
         docname, dispname = blog.references[target]
 
-        if "html" in app.builder.name:
+        # Avoid adding html to the atom.xml
+        if "html" in app.builder.name and "atom.xml" not in docname:
             internal = True
             uri = app.builder.get_relative_uri(refdoc, docname)
         else:
             internal = False
-            uri = blog.blog_baseurl + "/" + docname
+            uri = blog.blog_baseurl.rstrip("/") + "/" + docname
 
         newnode = nodes.reference("", "", internal=internal, refuri=uri, reftitle=dispname)
         if refexplicit:
@@ -656,16 +656,16 @@ def generate_atom_feeds(app):
     if not url:
         return
 
-    feed_path = os.path.join(app.builder.outdir, blog.blog_path, "atom.xml")
-
     feeds = [
         (
             blog.posts,
             blog.blog_path,
-            feed_path,
+            os.path.join(app.builder.outdir, blog.blog_path, feed_root + ".xml"),
             blog.blog_title,
-            os_path_join(url, blog.blog_path, "atom.xml"),
+            os_path_join(url, blog.blog_path, feed_root + ".xml"),
+            feed_templates,
         )
+        for feed_root, feed_templates in blog.blog_feed_templates.items()
     ]
 
     if blog.blog_feed_archives:
@@ -686,21 +686,23 @@ def generate_atom_feeds(app):
                 if not os.path.isdir(folder):
                     os.makedirs(folder)
 
-                feeds.append(
-                    (
-                        coll,
-                        coll.path,
-                        os.path.join(folder, "atom.xml"),
-                        blog.blog_title + " - " + header + " " + text_type(coll),
-                        os_path_join(url, coll.path, "atom.xml"),
+                for feed_root, feed_templates in blog.blog_feed_templates.items():
+                    feeds.append(
+                        (
+                            coll,
+                            coll.path,
+                            os.path.join(folder, feed_root + ".xml"),
+                            blog.blog_title + " - " + header + " " + text_type(coll),
+                            os_path_join(url, coll.path, feed_root + ".xml"),
+                            feed_templates,
+                        )
                     )
-                )
 
     # Config options
     feed_length = blog.blog_feed_length
     feed_fulltext = blog.blog_feed_fulltext
 
-    for feed_posts, pagename, feed_path, feed_title, feed_url in feeds:
+    for feed_posts, pagename, feed_path, feed_title, feed_url, feed_templates in feeds:
 
         feed = FeedGenerator()
         feed.id(blog.blog_baseurl)
@@ -709,7 +711,7 @@ def generate_atom_feeds(app):
         feed.subtitle(blog.blog_feed_subtitle)
         feed.link(href=feed_url)
         feed.language(app.config.language)
-        feed.generator("ABlog", ablog.__version__, "https://ablog.readthedocs.org")
+        feed.generator("ABlog", ablog.__version__, "https://ablog.readthedocs.org/")
 
         for i, post in enumerate(feed_posts):
             if feed_length and i == feed_length:
@@ -725,12 +727,28 @@ def generate_atom_feeds(app):
 
             feed_entry = feed.add_entry()
             feed_entry.id(post_url)
-            feed_entry.title(post.title)
             feed_entry.link(href=post_url)
             feed_entry.author({"name": author.name for author in post.author})
             feed_entry.pubDate(post.date.astimezone())
             feed_entry.updated(post.update.astimezone())
-            feed_entry.content(content=content, type="html")
+            for tag in post.tags:
+                feed_entry.category(
+                    dict(
+                        term=tag.name.strip().replace(" ", ""),
+                        label=tag.label,
+                    )
+                )
+
+            # Entry values that support templates
+            title = post.title
+            summary = " ".join(paragraph.astext() for paragraph in post.excerpt[0])
+            template_values = {}
+            for element in ("title", "summary", "content"):
+                if element in feed_templates:
+                    template_values[element] = jinja2.Template(feed_templates[element]).render(**locals())
+            feed_entry.title(template_values.get("title", title))
+            feed_entry.summary(template_values.get("summary", summary))
+            feed_entry.content(content=template_values.get("content", content), type="html")
 
         parent_dir = os.path.dirname(feed_path)
         if not os.path.isdir(parent_dir):
